# Changelog


All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## [0.0.5] - 2020-07-20

### Changed

- Pinned version of tifffile


## [0.0.4] - 2020-06-08

### Added

- Add posibility to specify more than one pipeline step

### Changed

- Make cellprofiler_pipeline_path CLI argument an absolute path in order to pass to docker


## [0.0.3] - 2020-06-06

### Changed

- Remove duplicated logging to console
- Remove unneccessary `ilastik` model copying when running in parallel
- Update demo data


## [0.0.1] - 2020-06-02

### Added

- First release
